@@ -1,6 +1,6 @@
-import pkg_resources
 import os
 import os.path
+import pkg_resources
 import sys
 
 
@@ -28,7 +28,8 @@ def delete_file(path):
 
 
 def pytest_configure(config):
-    for testpath in config.args:
+    # When calling pytest with --help `config` has no args:
+    for testpath in getattr(config, 'args', []):
         for root, subdirs, files in os.walk(testpath):
             for filename in files:
                 path = os.path.join(root, filename)
